@@ -1,8 +1,17 @@
+#define QT_FEATURE_xkbcommon 1
 #define QT_FEATURE_xcb 1
 #define QT_FEATURE_accessibility_atspi_bridge 1
 #define QT_FEATURE_angle_d3d11_qdtd -1
 #define QT_FEATURE_direct2d -1
+#define QT_FEATURE_direct2d1_1 -1
+#define QT_FEATURE_dxgi -1
+#define QT_FEATURE_direct3d11 -1
+#define QT_FEATURE_direct3d11_1 -1
+#define QT_FEATURE_direct3d9 -1
 #define QT_FEATURE_directfb -1
+#define QT_FEATURE_drm_atomic 1
+#define QT_FEATURE_dxgi1_2 -1
+#define QT_FEATURE_dxguid -1
 #define QT_FEATURE_egl 1
 #define QT_FEATURE_egl_x11 1
 #define QT_FEATURE_eglfs 1
@@ -17,6 +26,9 @@
 #define QT_FEATURE_eglfs_viv_wl -1
 #define QT_FEATURE_vsp2 -1
 #define QT_FEATURE_eglfs_vsp2 -1
+#define QT_FEATURE_xlib 1
+#define QT_FEATURE_xcb_xlib 1
+#define QT_FEATURE_eglfs_x11 1
 #define QT_FEATURE_evdev 1
 #define QT_FEATURE_freetype 1
 #define QT_FEATURE_system_freetype 1
@@ -41,14 +53,11 @@
 #define QT_FEATURE_tslib 1
 #define QT_FEATURE_tuiotouch 1
 #define QT_FEATURE_vnc 1
+#define QT_FEATURE_xcb_egl_plugin 1
+#define QT_FEATURE_xcb_glx_plugin 1
 #define QT_FEATURE_xcb_glx 1
-#define QT_FEATURE_xlib 1
-#define QT_FEATURE_xcb_xlib 1
 #define QT_FEATURE_xcb_native_painting 1
-#define QT_FEATURE_xcb_render 1
 #define QT_FEATURE_xcb_sm 1
-#define QT_FEATURE_xinput2 1
+#define QT_FEATURE_xcb_xinput 1
 #define QT_FEATURE_xkb 1
-#define QT_FEATURE_xkbcommon_evdev 1
-#define QT_FEATURE_xkbcommon_system 1
 #define QT_FEATURE_xrender 1
